@@ -1,23 +1,8 @@
-/***************************************************************************
- *   KSystemLog, a system log viewer tool                                  *
- *   Copyright (C) 2007 by Nicolas Ternisien                               *
- *   nicolas.ternisien@gmail.com                                           *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program; if not, write to the                         *
- *   Free Software Foundation, Inc.,                                       *
- *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2007 Nicolas Ternisien <nicolas.ternisien@gmail.com>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "levelPrintPage.h"
 
@@ -28,9 +13,9 @@
 #include <QGridLayout>
 #include <QLabel>
 
+#include "ksystemlog_debug.h"
 #include "logLevel.h"
 #include "logViewWidgetItem.h"
-#include "logging.h"
 
 #include "globals.h"
 
@@ -57,7 +42,8 @@ LevelPrintPage::LevelPrintPage(QWidget *parent)
     m_btnGroupLayout->setAlignment( Qt::AlignTop );
     */
 
-    int row = 0, col = 0;
+    int row = 0;
+    int col = 0;
     const auto logLevels = Globals::instance().logLevels();
     mLevelCheckBoxes.reserve(logLevels.count());
     for (LogLevel *level : logLevels) {
@@ -67,7 +53,7 @@ LevelPrintPage::LevelPrintPage(QWidget *parent)
         mBtnGroup->addButton(button, level->id());
         mBtnGroupLayout->addWidget(button, row, col);
 
-        logDebug() << "name: " << level->name() << " id: " << level->id();
+        qCDebug(KSYSTEMLOG) << "name: " << level->name() << " id: " << level->id();
 
         row++;
         if (row >= 4) {
