@@ -23,7 +23,11 @@ class JournaldConfiguration : public LogModeConfiguration
     Q_OBJECT
 
 public:
-    enum EntriesType { EntriesAll = 0, EntriesCurrentUser = 1, EntriesSystem = 2 };
+    enum EntriesType {
+        EntriesAll = 0,
+        EntriesCurrentUser = 1,
+        EntriesSystem = 2
+    };
 
     JournaldConfiguration();
 
