@@ -84,11 +84,7 @@ void JournaldLocalAnalyzer::watchLogFiles(bool enabled)
         mJournalWatchers.append(watcher);
         mWorkerMutex.unlock();
         connect(watcher, &JournalWatcher::finished, this, &JournaldLocalAnalyzer::readJournalInitialFinished);
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-        watcher->setFuture(QtConcurrent::run(this, &JournaldLocalAnalyzer::readJournal, mFilters));
-#else
         watcher->setFuture(QtConcurrent::run(&JournaldLocalAnalyzer::readJournal, this, mFilters));
-#endif
     } else {
         for (JournalWatcher *watcher : mJournalWatchers) {
             watcher->waitForFinished();
@@ -157,7 +153,7 @@ void JournaldLocalAnalyzer::readJournalFinished(ReadingMode readingMode)
         }
 
         // Add journald entries to the model.
-        int entriesInserted = updateModel(entries, readingMode);
+        int const entriesInserted = updateModel(entries, readingMode);
 
         mLogViewModel->endingMultipleInsertions(readingMode, entriesInserted);
 
@@ -200,16 +196,12 @@ void JournaldLocalAnalyzer::journalDescriptorUpdated(int fd)
     mJournalWatchers.append(watcher);
     mWorkerMutex.unlock();
     connect(watcher, &JournalWatcher::finished, this, &JournaldLocalAnalyzer::readJournalUpdateFinished);
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    watcher->setFuture(QtConcurrent::run(this, &JournaldLocalAnalyzer::readJournal, mFilters));
-#else
     watcher->setFuture(QtConcurrent::run(&JournaldLocalAnalyzer::readJournal, this, mFilters));
-#endif
 }
 
 QList<JournaldLocalAnalyzer::JournalEntry> JournaldLocalAnalyzer::readJournal(const QStringList &filters)
 {
-    QMutexLocker mutexLocker(&mWorkerMutex);
+    QMutexLocker const mutexLocker(&mWorkerMutex);
     QList<JournalEntry> entryList;
     sd_journal *journal;
 
@@ -272,7 +264,7 @@ bool JournaldLocalAnalyzer::prepareJournalReading(sd_journal *journal, const QSt
     }
 
     // Read number of entries allowed by KSystemLog configuration.
-    int maxEntriesNum = KSystemLogConfig::maxLines();
+    int const maxEntriesNum = KSystemLogConfig::maxLines();
 
     // Seek to cursor.
     if (mCursor) {
